@@ -7,21 +7,22 @@
 # License:  Standard 3-clause BSD; see "license.txt" for full license terms
 #           and contributor agreement.
 
+# We use __getitem__ side effects, which pylint doesn't like.
+# pylint: disable=pointless-statement
+
 """
     High-level access to HDF5 dataspace selections
 """
 
+from __future__ import absolute_import
+
+import six
+from six.moves import xrange    # pylint: disable=redefined-builtin
+
 import numpy as np
 
-from h5py import h5s, h5r
+from .. import h5s, h5r
 
-# Selection types for hyperslabs
-from h5py.h5s import SELECT_SET  as SET
-from h5py.h5s import SELECT_OR   as OR
-from h5py.h5s import SELECT_AND  as AND
-from h5py.h5s import SELECT_XOR  as XOR
-from h5py.h5s import SELECT_NOTB as NOTB
-from h5py.h5s import SELECT_NOTA as NOTA
 
 def select(shape, args, dsid):
     """ High-level routine to generate a selection from arbitrary arguments
@@ -82,6 +83,8 @@ def select(shape, args, dsid):
         if not isinstance(a, slice) and a is not Ellipsis:
             try:
                 int(a)
+                if isinstance(a, np.ndarray) and a.shape == (1,):
+                    raise Exception()
             except Exception:
                 sel = FancySelection(shape)
                 sel[args]
@@ -111,7 +114,7 @@ class _RegionProxy(object):
         """ Takes arbitrary selection terms and produces a RegionReference
         object.  Selection must be compatible with the dataset.
         """
-        selection = select(self.id.shape, args)
+        selection = select(self.id.shape, args, self.id)
         return h5r.create(self.id, '.', h5r.DATASET_REGION, selection.id)
 
 class Selection(object):
@@ -190,7 +193,7 @@ class PointSelection(Selection):
     """
 
     def _perform_selection(self, points, op):
-
+        """ Internal method which actually performs the selection """
         points = np.asarray(points, order='C', dtype='u8')
         if len(points.shape) == 1:
             points.shape = (1,points.shape[0])
@@ -297,8 +300,8 @@ class SimpleSelection(Selection):
         tshape.reverse()
         tshape = tuple(tshape)
 
-        chunks = tuple(x/y for x, y in zip(count, tshape))
-        nchunks = long(np.product(chunks))
+        chunks = tuple(x//y for x, y in zip(count, tshape))
+        nchunks = int(np.product(chunks))
 
         if nchunks == 1:
             yield self._id
@@ -311,71 +314,6 @@ class SimpleSelection(Selection):
                 yield sid
 
 
-class HyperSelection(Selection):
-
-    """
-        Represents multiple overlapping rectangular selections, combined
-        with set-like operators.  Result is a 1D shape, as with boolean array
-        selection.  Broadcasting is not supported for these selections.
-
-        When created, the entire dataspace is selected.  To make
-        adjustments to the selection, use the standard NumPy slicing
-        syntax, either via __getitem__ (as with simple selections) or via
-        __setitem__ and one of the supported operators:
-
-            >>> sel = HyperSelection((10,20))  # Initially 200 points
-            >>> sel[:,5:15] = False            # Now 100 points
-            >>> sel[:,10]   = True             # Now 110 points
-            >>> sel[...]    = XOR              # Now 90 points
-
-        Legal operators (in the h5py.selections module) are:
-           
-        SET
-            New selection, wiping out any old one
-       
-        AND, XOR, OR (or True)
-            Logical AND/XOR/OR between new and old selection
-
-        NOTA
-            Select only regions in new selection which don't intersect the old
-
-        NOTB (or False)
-            Select only regions in old selection which don't intersect the new
- 
-    """
-
-    def __getitem__(self, args):
-        self[args] = SET
-        return self
-
-    def __setitem__(self, args, op):
-
-        if not isinstance(args, tuple):
-            args = (args,)
- 
-        start, count, step, scalar = _handle_simple(self.shape, args)
-
-        if not op in (SET, OR, AND, XOR, NOTB, NOTA, True, False):
-            raise ValueError("Illegal selection operator")
-
-        if op is True:
-            op = OR
-        elif op is False:
-            op = NOTB
-
-        seltype = self._id.get_select_type()
-
-        if seltype == h5s.SEL_ALL:
-            self._id.select_hyperslab((0,)*len(self.shape), self.shape, op=h5s.SELECT_SET)
-       
-        elif seltype == h5s.SEL_NONE:
-            if op in (SET, OR, XOR, NOTA):
-                op = SET
-            else:
-                return
-
-        self._id.select_hyperslab(start, count, step, op=op)
-
 class FancySelection(Selection):
 
     """
@@ -417,17 +355,17 @@ class FancySelection(Selection):
                 except TypeError:
                     pass
                 else:
-                    if sorted(arg) != list(arg):
+                    list_arg = list(arg)
+                    adjacent = zip(list_arg[:-1], list_arg[1:])
+                    if any(fst >= snd for fst, snd in adjacent):
                         raise TypeError("Indexing elements must be in increasing order")
 
         if len(sequenceargs) > 1:
-            # TODO: fix this with broadcasting
             raise TypeError("Only one indexing vector or array is currently allowed for advanced selection")
         if len(sequenceargs) == 0:
-            # TODO: fallback to standard selection
             raise TypeError("Advanced selection inappropriate")
 
-        vectorlength = len(sequenceargs.values()[0])
+        vectorlength = len(list(sequenceargs.values())[0])
         if not all(len(x) == vectorlength for x in sequenceargs.values()):
             raise TypeError("All sequence arguments must have the same length %s" % sequenceargs)
 
@@ -437,7 +375,7 @@ class FancySelection(Selection):
         argvector = []
         for idx in xrange(vectorlength):
             entry = list(args)
-            for position, seq in sequenceargs.iteritems():
+            for position, seq in six.iteritems(sequenceargs):
                 entry[position] = seq[idx]
             argvector.append(entry)
 
@@ -476,7 +414,7 @@ def _expand_ellipsis(args, rank):
 
     final_args = []
     n_args = len(args)
-    for idx, arg in enumerate(args):
+    for arg in args:
 
         if arg is Ellipsis:
             final_args.extend( (slice(None,None,None),)*(rank-n_args+1) )
