@@ -11,45 +11,67 @@
 #
 #-
 
-"""
-h5py completer extension for ipython. This completer is automatically loaded
-when h5py is imported within ipython. It will let you do things like::
-
-  f=File('foo.h5')
-  f['<tab>
-  # or:
-  f['ite<tab>
-
-which will do tab completion based on the subgroups of `f`. Also::
-
-  f['item1'].at<tab>
-
-will perform tab completion for the attributes in the usual way. This should
-also work::
-
-  a = b = f['item1'].attrs.<tab>
-
-as should::
-
-  f['item1/item2/it<tab>
+# pylint: disable=eval-used,protected-access
 
 """
+    This is the h5py completer extension for ipython.  It is loaded by
+    calling the function h5py.enable_ipython_completer() from within an
+    interactive IPython session.
+    
+    It will let you do things like::
+
+      f=File('foo.h5')
+      f['<tab>
+      # or:
+      f['ite<tab>
+
+    which will do tab completion based on the subgroups of `f`. Also::
+
+      f['item1'].at<tab>
+
+    will perform tab completion for the attributes in the usual way. This should
+    also work::
+
+      a = b = f['item1'].attrs.<tab>
+
+    as should::
+
+      f['item1/item2/it<tab>
+"""
+
+from __future__ import absolute_import
 
 import posixpath
 import re
+import readline
+from ._hl.attrs import AttributeManager
+from ._hl.base import HLObject
+
 
 try:
+    # >=ipython-1.0
+    from IPython import get_ipython
+except ImportError:
+    try:
+        # support >=ipython-0.11, <ipython-1.0
+        from IPython.core.ipapi import get as get_ipython
+    except ImportError:
+        # support <ipython-0.11
+        from IPython.ipapi import get as get_ipython
+try:
+    # support >=ipython-0.11
     from IPython.utils import generics
-    from IPython.core.error import TryNext
-    from IPython.core.ipapi import get as ipget
 except ImportError:
     # support <ipython-0.11
     from IPython import generics
-    from IPython.ipapi import TryNext, get as ipget
 
-import readline
-
-from h5py.highlevel import AttributeManager, HLObject
+try:
+    from IPython.core.error import TryNext
+except ImportError:
+    try:
+        from IPython import TryNext
+    except ImportError:
+        from IPython.ipapi import TryNext
 
 re_attr_match = re.compile(r"(?:.*\=)?(.+\[.*\].*)\.(\w*)$")
 re_item_match = re.compile(r"""(?:.*\=)?(.*)\[(?P<s>['|"])(?!.*(?P=s))(.*)$""")
@@ -57,12 +79,13 @@ re_object_match = re.compile(r"(?:.*\=)?(.+?)(?:\[)")
 
 
 def _retrieve_obj(name, context):
+    """ Filter function for completion. """
+
     # we don't want to call any functions, but I couldn't find a robust regex
     # that filtered them without unintended side effects. So keys containing
     # "(" will not complete.
-    try:
-        assert '(' not in name
-    except AssertionError:
+    
+    if '(' in name:
         raise ValueError()
 
     try:
@@ -81,16 +104,20 @@ def h5py_item_completer(context, command):
 
     try:
         obj = _retrieve_obj(base, context)
-    except:
+    except Exception:
         return []
 
-    path, target = posixpath.split(item)
-    if path:
-        items = (posixpath.join(path, name) for name in obj[path].iterkeys())
-    else:
-        items = obj.iterkeys()
-    items = list(items)
+    path, _ = posixpath.split(item)
 
+    try:
+        if path:
+            items = (posixpath.join(path, name) for name in obj[path].keys())
+        else:
+            items = obj.keys()
+    except AttributeError:
+        return []
+
+    items = list(items)
     readline.set_completer_delims(' \t\n`!@#$^&*()=+[{]}\\|;:\'",<>?')
 
     return [i for i in items if i[:len(item)] == item]
@@ -104,7 +131,7 @@ def h5py_attr_completer(context, command):
 
     try:
         obj = _retrieve_obj(base, context)
-    except:
+    except Exception:
         return []
 
     attrs = dir(obj)
@@ -116,19 +143,19 @@ def h5py_attr_completer(context, command):
     omit__names = None
     try:
         # support >=ipython-0.12
-        omit__names = ipget().Completer.omit__names
+        omit__names = get_ipython().Completer.omit__names
     except AttributeError:
         pass
     if omit__names is None:
         try:
             # support ipython-0.11
-            omit__names = ipget().readline_omit__names
+            omit__names = get_ipython().readline_omit__names
         except AttributeError:
             pass
     if omit__names is None:
         try:
             # support <ipython-0.11
-            omit__names = ipget().options.readline_omit__names
+            omit__names = get_ipython().options.readline_omit__names
         except AttributeError:
             omit__names = 0
     if omit__names == 1:
@@ -142,6 +169,7 @@ def h5py_attr_completer(context, command):
 
 
 def h5py_completer(self, event):
+    """ Completer function to be loaded into IPython """
     base = re_object_match.split(event.line)[1]
 
     if not isinstance(self._ofind(base)['obj'], (AttributeManager, HLObject)):
@@ -161,6 +189,7 @@ def h5py_completer(self, event):
 
 
 def load_ipython_extension(ip=None):
+    """ Load completer function into IPython """
     if ip is None:
-        ip = ipget()
+        ip = get_ipython()
     ip.set_hook('complete_command', h5py_completer, re_key=r"(?:.*\=)?(.+?)\[")
